@@ -540,7 +540,7 @@ readEnrichment <- function (pattern = "Chrom", signalFile, transcriptFile = FALS
     formal <- as.list(names(formals(as.character(sysCall))))
     names(formal) <- formal
     if (is.null(names(argsSNP))) {
-        names(argsSNP) <- names(formal)[seq(length(argsSNP))]
+        names(argsSNP) <- names(formal)[seq_along(argsSNP)]
     } else {
         emptyNames <- which(names(argsSNP)=="")
         names(argsSNP)[emptyNames] <- names(formal)[emptyNames]
